### -*- coding: utf-8 -*- #############################################
# Разработано компанией Ключевые Решения (http://keysolutions.ru/)
# Все права защищены, 2006-2007
#
# Developed by Key Solutions (http://keysolutions.ru/)
# All right reserved, 2006-2007
#######################################################################
"""Interfaces for the Zope 3 based mailer package

$Id: interfaces.py 23861 2007-11-25 00:13:00Z xen $
"""
__author__  = "Anatoly Zaretsky"
__license__ = "ZPL"
__version__ = "$Revision: 23861 $"
__date__ = "$Date: 2007-11-25 02:13:00 +0200 (Sun, 25 Nov 2007) $"

from zope.interface import Interface
from zope.schema import Choice

from ks.mailer import _

class IMailer(Interface):

    template = Choice(
        title=_(u"Template"),
        vocabulary="Message Template Vocabulary")

    def execute(**kw):
        pass


class ITemplateAdaptable(Interface):
    pass


class ITemplate(ITemplateAdaptable):

    def __call__(**kw):
        pass
